/*
 * Copyright (c) 2016-2021 Arm Limited.
 *
 * SPDX-License-Identifier: MIT
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
#include "arm_compute/core/IKernel.h"

using namespace arm_compute;

const Window &IKernel::window() const
{
    return _window;
}

IKernel::IKernel()
    : _window()
{
    // Create an empty window to make sure the children classes set the window values themselves
    _window.set(Window::DimX, Window::Dimension(0, 0, 1));
    _window.set(Window::DimY, Window::Dimension(0, 0, 1));
}

bool IKernel::is_parallelisable() const
{
    return true;
}

BorderSize IKernel::border_size() const
{
    return BorderSize(0);
}

bool IKernel::is_window_configured() const
{
    return !((_window.x().start() == _window.x().end()) && (_window.x().end() == 0));
}

void IKernel::configure(const Window &window)
{
    _window = window;
}
